import { Response } from 'centra';
import { UserLogger } from './requests';
declare type apiKeysObject = {
    [listname: string]: string;
};
/**
 * This is a fallback type
 * to make BLAPI compatible with typescript code that does not use discord.js
 */
declare class Collection<K, T> extends Map<K, T> {
    [key: string]: any;
}
/**
 * This is a fallback type
 * to make BLAPI compatible with typescript code that does not use discord.js
 */
declare type DiscordJSClientFallback = {
    user: {
        id: string;
        [k: string]: any;
    } | null;
    shard: ({
        count: number;
        [k: string]: any;
    } & ({
        ids: number[];
    } | {
        id: number;
    })) | null;
    guilds: {
        cache: Collection<string, ({
            shardID: number;
        } | {
            shardId: number;
        }) & {
            [k: string]: any;
        }>;
    };
    ws: {
        shards: Collection<number, {
            id: number;
            [k: string]: any;
        }>;
        [k: string]: any;
    };
    [k: string]: any;
};
declare type LogOptions = boolean | {
    extended?: boolean;
    logger?: UserLogger;
};
/**
 * This function is for automated use with discord.js
 * @param discordClient Client via wich your code is connected to Discord
 * @param apiKeys A JSON object formatted like: {"botlist name":"API Keys for that list", etc.}
 * @param repeatInterval Number of minutes until you want to post again, leave out to use 30
 */
export declare function handle(discordClient: DiscordJSClientFallback, apiKeys: apiKeysObject, repeatInterval?: number): Promise<void>;
/**
 * For when you don't use discord.js or just want to post to manual times
 * @param guildCount Integer value of guilds your bot is serving
 * @param botId Snowflake of the ID the user your bot is using
 * @param apiKeys A JSON object formatted like: {"botlist name":"API Keys for that list", etc.}
 * @param shardId (optional) The shard ID, which will be used to identify the
 * shards valid for posting
 * (and for super efficient posting with BLAPIs own distributer when not using botBlock)
 * @param shardCount (optional) The number of shards the bot has, which is posted to the lists
 * @param shards (optional) An array of guild counts of each single shard
 *  (this should be a complete list, and only a single shard will post it)
 */
export declare function manualPost(guildCount: number, botID: string, apiKeys: apiKeysObject, shard_id?: number, shard_count?: number, shards?: Array<number>): Promise<Array<Response | {
    error: any;
}>>;
export declare function setLogging(logOptions: LogOptions): void;
export declare function setBotblock(useBotblock: boolean): void;
export {};
